==> tuia-advert-center-api-2.2.18-sources.jar: cn/com/duiba/tuia/core/api/dto/AdvertSupportReqDto.java <==
package cn.com.duiba.tuia.core.api.dto;

import java.util.Date;
import java.util.List;

public class AdvertSupportReqDto {
    private List<Long> advertIds;

    private Long advertId;

    private List<Long> orientPackageIds;

    private Long OrientId;

    private List<Long> appIds;

    private Date startDate;

    private Date endDate;

    private Integer dataType;

    public List<Long> getAdvertIds() {
        return advertIds;
    }

    public void setAdvertIds(List<Long> advertIds) {
        this.advertIds = advertIds;
    }

    public List<Long> getOrientPackageIds() {
        return orientPackageIds;
    }

    public void setOrientPackageIds(List<Long> orientPackageIds) {
        this.orientPackageIds = orientPackageIds;
    }

    public List<Long> getAppIds() {
        return appIds;
    }

    public void setAppIds(List<Long> appIds) {
        this.appIds = appIds;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public Integer getDataType() {
        return dataType;
    }

    public void setDataType(Integer dataType) {
        this.dataType = dataType;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getOrientId() {
        return OrientId;
    }

    public void setOrientId(Long orientId) {
        OrientId = orientId;
    }
}

==> tuia-advert-center-api-2.4.3-sources.jar: cn/com/duiba/tuia/core/api/dto/AdvertSupportReqDto.java <==
package cn.com.duiba.tuia.core.api.dto;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class AdvertSupportReqDto implements Serializable {

    private static final long serialVersionUID = 4723508547074892387L;

    private List<Long> advertIds;

    private Long advertId;

    private List<Long> orientPackageIds;

    private Long OrientId;

    private List<Long> appIds;

    private Date startDate;

    private Date endDate;

    private Integer dataType;

    public List<Long> getAdvertIds() {
        return advertIds;
    }

    public void setAdvertIds(List<Long> advertIds) {
        this.advertIds = advertIds;
    }

    public List<Long> getOrientPackageIds() {
        return orientPackageIds;
    }

    public void setOrientPackageIds(List<Long> orientPackageIds) {
        this.orientPackageIds = orientPackageIds;
    }

    public List<Long> getAppIds() {
        return appIds;
    }

    public void setAppIds(List<Long> appIds) {
        this.appIds = appIds;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public Integer getDataType() {
        return dataType;
    }

    public void setDataType(Integer dataType) {
        this.dataType = dataType;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getOrientId() {
        return OrientId;
    }

    public void setOrientId(Long orientId) {
        OrientId = orientId;
    }
}
